summaryrefslogtreecommitdiffstats
path: root/kipi-plugins/findimages/finddupplicatedialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kipi-plugins/findimages/finddupplicatedialog.cpp')
-rw-r--r--kipi-plugins/findimages/finddupplicatedialog.cpp112
1 files changed, 56 insertions, 56 deletions
diff --git a/kipi-plugins/findimages/finddupplicatedialog.cpp b/kipi-plugins/findimages/finddupplicatedialog.cpp
index cd6cfe5..0ff548e 100644
--- a/kipi-plugins/findimages/finddupplicatedialog.cpp
+++ b/kipi-plugins/findimages/finddupplicatedialog.cpp
@@ -20,21 +20,21 @@
//
//////////////////////////////////////////////////////////////////////////////
-// Include files for Qt
-
-#include <qlabel.h>
-#include <qvbox.h>
-#include <qgroupbox.h>
-#include <qlayout.h>
-#include <qcombobox.h>
-#include <qwhatsthis.h>
-#include <qcheckbox.h>
-#include <qlineedit.h>
-#include <qspinbox.h>
-#include <qlistview.h>
-#include <qheader.h>
-#include <qpushbutton.h>
-#include <qfileinfo.h>
+// Include files for TQt
+
+#include <tqlabel.h>
+#include <tqvbox.h>
+#include <tqgroupbox.h>
+#include <tqlayout.h>
+#include <tqcombobox.h>
+#include <tqwhatsthis.h>
+#include <tqcheckbox.h>
+#include <tqlineedit.h>
+#include <tqspinbox.h>
+#include <tqlistview.h>
+#include <tqheader.h>
+#include <tqpushbutton.h>
+#include <tqfileinfo.h>
// Include files for KDE
@@ -73,9 +73,9 @@
namespace KIPIFindDupplicateImagesPlugin
{
-FindDuplicateDialog::FindDuplicateDialog( KIPI::Interface* interface, QWidget *parent)
+FindDuplicateDialog::FindDuplicateDialog( KIPI::Interface* interface, TQWidget *tqparent)
: KDialogBase( IconList, i18n("Configure"), Help|Ok|Cancel,
- Ok, parent, "FindDuplicateDialog", true, false ),
+ Ok, tqparent, "FindDuplicateDialog", true, false ),
m_interface( interface )
{
setCaption(i18n("Find Duplicate Images"));
@@ -105,7 +105,7 @@ FindDuplicateDialog::FindDuplicateDialog( KIPI::Interface* interface, QWidget *p
m_helpButton = actionButton( Help );
KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
helpMenu->menu()->removeItemAt(0);
- helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+ helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQT_SLOT(slotHelp()), 0, -1, 0);
m_helpButton->setPopup( helpMenu->menu() );
}
@@ -126,9 +126,9 @@ void FindDuplicateDialog::setupSelection(void)
i18n("Album's Selection"),
BarIcon("folder_image", KIcon::SizeMedium));
- QVBoxLayout *layout = new QVBoxLayout(page_setupSelection, 0, spacingHint() );
+ TQVBoxLayout *tqlayout = new TQVBoxLayout(page_setupSelection, 0, spacingHint() );
m_imageCollectionSelector = new KIPI::ImageCollectionSelector(page_setupSelection, m_interface);
- layout->addWidget(m_imageCollectionSelector);
+ tqlayout->addWidget(m_imageCollectionSelector);
}
@@ -136,24 +136,24 @@ void FindDuplicateDialog::setupSelection(void)
void FindDuplicateDialog::setupPageMethod(void)
{
- QString whatsThis;
+ TQString whatsThis;
page_setupMethod = addPage( i18n("Method & Cache"), i18n("Find-Duplicates Method & Cache Configuration"),
BarIcon("run", KIcon::SizeMedium ) );
- QVBoxLayout *vlay = new QVBoxLayout( page_setupMethod, 0, spacingHint() );
+ TQVBoxLayout *vlay = new TQVBoxLayout( page_setupMethod, 0, spacingHint() );
//---------------------------------------------
- QGroupBox * groupBox1 = new QGroupBox( 2, Qt::Horizontal, i18n("Method"), page_setupMethod );
- groupBox1->layout()->setSpacing( 6 );
- groupBox1->layout()->setMargin( 11 );
+ TQGroupBox * groupBox1 = new TQGroupBox( 2, Qt::Horizontal, i18n("Method"), page_setupMethod );
+ groupBox1->tqlayout()->setSpacing( 6 );
+ groupBox1->tqlayout()->setMargin( 11 );
- QLabel *m_labelsearchMethod = new QLabel( i18n("Search method:"), groupBox1 );
- m_findMethod = new QComboBox(false, groupBox1);
+ TQLabel *m_labelsearchMethod = new TQLabel( i18n("Search method:"), groupBox1 );
+ m_findMethod = new TQComboBox(false, groupBox1);
m_findMethod->insertItem(i18n("Almost"), MethodAlmost);
m_findMethod->insertItem(i18n("Fast"), MethodFast);
m_findMethod->setCurrentItem ( MethodAlmost );
- QWhatsThis::add( m_findMethod, i18n("<p>Select here the search method used to find duplicate "
+ TQWhatsThis::add( m_findMethod, i18n("<p>Select here the search method used to find duplicate "
"images in the Albums database.<p>"
"<b>Almost</b>: the algorithm calculates an approximate difference between images. "
"This method is slower but robust. You can affine the thresholding using the "
@@ -162,48 +162,48 @@ void FindDuplicateDialog::setupPageMethod(void)
"This method is faster but is not as robust."));
m_labelsearchMethod->setBuddy( m_findMethod );
- (void) new QLabel (i18n("Approximate threshold:"), groupBox1);
+ (void) new TQLabel (i18n("Approximate threshold:"), groupBox1);
m_approximateThreshold = new KIntNumInput(88, groupBox1);
m_approximateThreshold->setRange(60, 100, 1, true );
- QWhatsThis::add( m_approximateThreshold, i18n("<p>Select here the approximate threshold "
- "value, as a percentage, for the 'Almost' find-duplicates method. "
+ TQWhatsThis::add( m_approximateThreshold, i18n("<p>Select here the approximate threshold "
+ "value, as a percentage, for the 'Almost' tqfind-duplicates method. "
"This value is used by the algorithm to distinguish two "
"similar images. The default value is 88.") );
vlay->addWidget( groupBox1 );
//---------------------------------------------
- QGroupBox * groupBox2 = new QGroupBox( 1, Qt::Horizontal, i18n("Cache Maintenance"), page_setupMethod );
- new QLabel(i18n("The find-duplicate-images process uses a cache folder for images' fingerprints\n"
+ TQGroupBox * groupBox2 = new TQGroupBox( 1, Qt::Horizontal, i18n("Cache Maintenance"), page_setupMethod );
+ new TQLabel(i18n("The tqfind-duplicate-images process uses a cache folder for images' fingerprints\n"
"to speed up the analysis of items from Albums."), groupBox2);
- QPushButton* updateCache = new QPushButton( groupBox2, "UpdateCache" );
+ TQPushButton* updateCache = new TQPushButton( groupBox2, "UpdateCache" );
updateCache->setText(i18n( "&Update Cache" ));
- QWhatsThis::add( updateCache, i18n("<p>Update the cache data for the selected Albums.") );
- QPushButton* purgeCache = new QPushButton( groupBox2, "PurgeCacheAlbumsSelected" );
+ TQWhatsThis::add( updateCache, i18n("<p>Update the cache data for the selected Albums.") );
+ TQPushButton* purgeCache = new TQPushButton( groupBox2, "PurgeCacheAlbumsSelected" );
purgeCache->setText(i18n( "&Purge Cache (Albums Selected)" ));
- QWhatsThis::add( purgeCache, i18n("<p>Purge the cache data for the selected Albums.") );
- QPushButton* purgeAllCache = new QPushButton( groupBox2, "PurgeAllCache" );
+ TQWhatsThis::add( purgeCache, i18n("<p>Purge the cache data for the selected Albums.") );
+ TQPushButton* purgeAllCache = new TQPushButton( groupBox2, "PurgeAllCache" );
purgeAllCache->setText(i18n( "&Purge All Caches" ));
- QWhatsThis::add( purgeAllCache, i18n("<p>Purge the cache data for all Albums.") );
+ TQWhatsThis::add( purgeAllCache, i18n("<p>Purge the cache data for all Albums.") );
vlay->addWidget( groupBox2 );
vlay->addStretch(1);
//---------------------------------------------
- connect(m_findMethod, SIGNAL(activated(int)),
- this, SLOT(slotfindMethodChanged(int)));
+ connect(m_findMethod, TQT_SIGNAL(activated(int)),
+ this, TQT_SLOT(slotfindMethodChanged(int)));
- connect(updateCache, SIGNAL(clicked()),
- this, SLOT(slotUpdateCache()));
+ connect(updateCache, TQT_SIGNAL(clicked()),
+ this, TQT_SLOT(slotUpdateCache()));
- connect(purgeCache, SIGNAL(clicked()),
- this, SLOT(slotPurgeCache()));
+ connect(purgeCache, TQT_SIGNAL(clicked()),
+ this, TQT_SLOT(slotPurgeCache()));
- connect(purgeAllCache, SIGNAL(clicked()),
- this, SLOT(slotPurgeAllCache()));
+ connect(purgeAllCache, TQT_SIGNAL(clicked()),
+ this, TQT_SLOT(slotPurgeAllCache()));
slotfindMethodChanged(m_findMethod->currentItem());
}
@@ -233,13 +233,13 @@ void FindDuplicateDialog::slotfindMethodChanged(int index)
void FindDuplicateDialog::slotUpdateCache(void)
{
- QValueList<KIPI::ImageCollection> albumsList = getSelectedAlbums();
- QStringList albumsListPath;
+ TQValueList<KIPI::ImageCollection> albumsList = getSelectedAlbums();
+ TQStringList albumsListPath;
- for( QValueList<KIPI::ImageCollection>::ConstIterator album = albumsList.begin() ;
+ for( TQValueList<KIPI::ImageCollection>::ConstIterator album = albumsList.begin() ;
album != albumsList.end() ; ++album )
{
- if ( !albumsListPath.contains( (*album).path().path() ) )
+ if ( !albumsListPath.tqcontains( (*album).path().path() ) )
albumsListPath.append( (*album).path().path() );
}
@@ -254,14 +254,14 @@ void FindDuplicateDialog::slotUpdateCache(void)
void FindDuplicateDialog::slotPurgeCache(void)
{
- QValueList<KIPI::ImageCollection> albumsList = getSelectedAlbums();
+ TQValueList<KIPI::ImageCollection> albumsList = getSelectedAlbums();
- QStringList albumsListPath;
+ TQStringList albumsListPath;
- for( QValueList<KIPI::ImageCollection>::ConstIterator album = albumsList.begin() ;
+ for( TQValueList<KIPI::ImageCollection>::ConstIterator album = albumsList.begin() ;
album != albumsList.end() ; ++album )
{
- if ( !albumsListPath.contains( (*album).path().path() ) )
+ if ( !albumsListPath.tqcontains( (*album).path().path() ) )
albumsListPath.append( (*album).path().path() );
}
@@ -296,7 +296,7 @@ void FindDuplicateDialog::slotOk()
/////////////////////////////////////////////////////////////////////////////////////////////
-QValueList<KIPI::ImageCollection> FindDuplicateDialog::getSelectedAlbums() const
+TQValueList<KIPI::ImageCollection> FindDuplicateDialog::getSelectedAlbums() const
{
return m_imageCollectionSelector->selectedImageCollections();
}